Reporting Bugs
==============

To report bugs on the Checkbox project you will need a launchpad account. You
may find `instructions on how to create one
<https://help.launchpad.net/YourAccount/NewAccount>`_ useful. Once you have an
account you can `report bugs
<https://bugs.launchpad.net/checkbox-project/+filebug>`_.

On that page you can select the project you wish to file the bug on (we use a
number of projects to coordinate releases and we prefer to have bugs associated
with appropriate part of Checkbox). If you know the right project to use, just
use it and file the bug. If you don't know Checkbox internals that much or are
in doubt just file it on the base 'Checkbox' project (you can use `this direct
link <https://bugs.launchpad.net/checkbox/+filebug>`_.) A member of the
development team will review your bug and re-assign it to the appropriate
location. The bug number will not change when that happens.
